@@ -1,5 +1,3 @@
-from rrshare.rqUpdate.update_ROE_CF_SR_INC import record_roe_cf_sr_inc 
-
 from rrshare.rqUpdate.update_stock_day import record_stock_day
 from rrshare.rqUpdate.update_swl_day import record_swl_day
 from rrshare.rqUpdate.update_swl_rs_valuation import record_swl_rs_valuation
@@ -8,8 +6,6 @@ from rrshare.rqUpdate.update_stock_RS_OH_MA import record_stock_PRS, record_stoc
 
 
 def main_record():
-    record_roe_cf_sr_inc()
-
     record_stock_day()
     record_swl_day()
 
