@@ -1,23 +1,17 @@
-#jq, pro
-from rrshare.rqFetch.rqJoinquant import jq
+# pro
 from rrshare.rqFetch.rqTusharepro import pro
 
 # rqFetch
 
-from rrshare.rqFetch.fetch_basic_tusharepro import (pro, fetch_delist_stock,
+from rrshare.rqFetch.rqCodeName import (swl_index_to_name,stock_code_to_name,stock_code_belong_swl_name)
+from rrshare.rqFetch.fetch_swl_daily import fetch_swl_daily_tspro_adv
+from rrshare.rqFetch.fetch_basic_tusharepro import (fetch_delist_stock,
                                                         fetch_get_stock_list,
                                                         fetch_get_stock_list_adj)
-                                                        
-from rrshare.rqFetch.fetch_industry_swl import (swl_index_name,stock_belong_swl,
-                                                stock_belong_swl_all_level)
-
 from rrshare.rqFetch.rqFetchSnapshot_eq import (
         fetch_realtime_price_all, 
         fetch_realtime_price_stock)
 
-from rrshare.rqFetch.rqCodeName import (stock_code_name_all, swl_index_name_all,
-                        stock_code_to_name, swl_index_to_name)
-
 from rrshare.rqFetch.fetch_stock_day_adj_fillna_from_tusharepro import (
                 fetch_stock_day_adj_fillna_from_tusharepro,
                 fetch_realtime_price_stock_day_adj)
