@@ -2,12 +2,12 @@
 
 
 #save stock_day, swl_day
-from rrshare.rqSU.save_tusharepro_pg import (rq_save_stock_day_pg,
+from rrshare.rqSU.save_tusharepro_pg import (
+                                            #rq_save_stock_day_pg,
                                              rq_save_swl_day_pg,
                                              rq_save_stock_list_pg,
-                                             rq_save_swl_list_pg,
-                                             rq_save_stock_belong_swl_pg,
                                              rq_save_stock_day_adj_fillna_pg
                                              )
+from rrshare.rqSU.save_industry_swl_list import rq_save_swl_industry_list_stock_belong
 
 
