@@ -74,8 +74,8 @@ def write_stock_RS_OH_MA():
     st.text('相对强度 ')
     table_name='stock_RS_OH_MA' if  current < start else 'stock_RS_OH_MA_new'
     
-    cols = ['cn_name','code', 'close','pct_chg','OH',"OL","sw_l3", 'rs_10']
-    cols2= ['cn_name','code', 'close','pct_chg','ma20','ma250','rs_10','rs_250','OH',"OL","sw_l3"]
+    cols = ['cn_name','code', 'close','pct_chg','OH',"OL","swl_L3", 'rs_10','rs_250']
+    cols2= ['cn_name','code', 'close','pct_chg','ma20','ma250','rs_10','rs_250','OH',"OL","swl_L3"]
     try:
         #table_name='stock_RS_OH_MA_new'
         st.write(table_name)
@@ -85,22 +85,26 @@ def write_stock_RS_OH_MA():
             data = out_df_items(df)
             df2 = data[0][cols]
             df2 = df2.dropna(axis=0,how='any')
-            df2 = df2.sort_values(by='sw_l3')
+            df2 = df2.sort_values(by='swl_L3')
             code = st.text_input('Input stock code:','300146')
             df1 = data[0][cols2]
             st.dataframe(df1[df1.code == code].T)
             st.write(data[1], data[2])
-            st.text('相对强度 all')
+            #st.text('相对强度 all')
+            st.write('涨停', str(len(data[0][data[0].pct_chg > 9.90])),'只' , ',   ',\
+                    '跌停', str(len(data[0][data[0].pct_chg < -9.90])),'只' )
             st.write(data[0], width=1200, height=600)
         if table_name == 'stock_RS_OH_MA':
             data = df
             df2 = df[cols]
             df2 = df2.dropna(axis=0,how='any')
-            df2 = df2.sort_values(by='sw_l3')
+            df2 = df2.sort_values(by='swl_L3')
             code = st.text_input('Input stock code:','300146')
             df1 = data[cols2]
             st.dataframe(df1[df1.code == code].T)
-            st.text('相对强度 all')
+            #st.text('相对强度 all')
+            st.write('涨停', str(len(df[df.pct_chg > 9.90])),'只', ',', \
+                     '跌停', str(len(df[df.pct_chg < -9.90])),'只')
             st.write(df, width=1200, height=600)
         
         st.write('一年新高', str(len(df[df.OH >98])),'只' )
@@ -111,8 +115,6 @@ def write_stock_RS_OH_MA():
     except Exception as e:
         print(e)    
 
-    
-    
         
 def stock_select_PRS(table_name='stock_select_PRS'):
     try:
@@ -163,71 +165,11 @@ def other_info():
     st.write('HK','http://q.10jqka.com.cn/hk/indexYs/')
     st.write('US','http://q.10jqka.com.cn/usa/indexDefer/')
     st.write('航运指数', 'https://www.sse.net.cn/index/singleIndex?indexType=ccfi')
+    st.write('中国新造船指数', 'https://www.cnpi.org.cn/index.html')
     st.write('global index ','http://q.10jqka.com.cn/global/')
     st.write('bond','https://cn.investing.com/rates-bonds/u.s.-10-year-bond-yield')
     st.write('myselect','http://quote.eastmoney.com/zixuan/?from=home')
 
-
-def get_RS_OH_MA_oneStock(code, table_name="", N=250):
-    startTD = rq_util_get_pre_trade_date(rq_util_get_last_tradedate(), N)
-    startTD_str = f"'{startTD}'"
-    code_str = f"'{code}'"
-    sql = f"SELECT * FROM RS_RT_OH_MA_fillna WHERE code={code_str}"# AND trade_date >= {startTD_str}"
-    df = pd.read_sql(sql,conn)
-    df = df.set_index('trade_date')
-    #df.index = pd.to_datetime(df.index)
-    #df = df.drop(['index'], axis=1)
-    return df
-
-
-def industry_stocks_select():
-    st.text('swl industry stocks')
-    swl1 = get_industries('sw_l2', lastTD)
-    swl1_dict = dict(zip(swl1.name, swl1.index))
-    ind = st.sidebar.selectbox('sw industry select stocks:',(swl1.name.values))
-    ind_code = swl1_dict.get(ind)
-    ind_stocks = get_industry_stocks(ind_code)
-    #st.write('', ind_stocks)
-    print(ind_stocks)
-    df = pd.read_sql_table('roe_gw_sr_cf_inc', conn)
-    #print(df.head())
-    #print(df.columns)
-    #print(df['index'])
-    ind_stocks_fundmental = df[df['index'].isin(ind_stocks)]
-    st.write("", ind_stocks_fundmental)
-
-def chart_selectSec_rps():
-    selectSecs = ReadWriteCSV('data','selectSecs.csv').read_input_csv()
-    secs= st.sidebar.selectbox('select stocks:',selectSecs)
-
-
-def oneStock_rps(code,N=60):
-    df = get_RS_OH_MA_oneStock(code, N=N)
-    #df['name'] = df['code'].apply(lambda x: stockNameDict[code])
-    #df['swl3'] = df['code'].apply(lambda x : stockIndustry(x, industry_type='sw_l3')['Industry'].values[0])
-    print(df.tail())
-    return df 
-
-
-def oneStock_rps_chart(col_rank=['rank_5','rank10','rank_20', 'rank_60','rank_120','rank_250'],
-                       col_ma=['H','L','close','ma5','ma10', 'ma20','ma60','ma120','ma250'],
-                       col_chg=['pct_chg','OH','OL'],
-                       N=60):
-    st.text('个股的技术指标, 输入交易代码')
-    title= st.text_input('600519','600196')
-    #st.write('The current  stock code is', title)
-    code= str(title)# f'{title}.XSHG' if title.startswith('6') else f'{title}.XSHE'
-    #indus = stockIndustry(code, industry_type='sw_l3')['Industry'].values
-    #st.text(f"{code}: {stockNameDict[code]}, {indus}")
-    df =  get_RS_OH_MA_oneStock(code, N=N)
-    st.line_chart(df[col_rank],width=900, height=400, use_container_width=False)
-    st.line_chart(df[col_ma],width=900, height=400, use_container_width=False)
-    st.line_chart(df[col_chg],width=900, height=400, use_container_width=False)
-    st.dataframe(oneStock_rps(code=code, N=20).style.highlight_max(axis=0),width=900, height=600)
-    #st.text('个股基本面')
-    #df_f = get_fundmentals()
-    #df_f = df_f[df_f.index == code]
-    
          
 def main():
     selects = st.sidebar.selectbox(
