@@ -7,7 +7,7 @@ if [ $? -eq 0 ]; then
   echo "streamlit is already runned"
 else
  # pkill -9 streamlit && 
- /home/rome/.local/bin/streamlit run /home/rome/rrshare/rrshare/rqWeb/stock_RS_OH_MA_to_streamlit.py
+streamlit run ~/rrshare/rrshare/rqWeb/stock_RS_OH_MA_to_streamlit.py
 fi
 
 
